# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'IscsiTargetAclMode',
]


class IscsiTargetAclMode(str, Enum):
    """
    Mode for Target connectivity.
    """
    DYNAMIC = "Dynamic"
    STATIC = "Static"
