# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'CacheIdentityType',
    'NfsAccessRuleAccess',
    'NfsAccessRuleScope',
    'ProvisioningStateType',
    'StorageTargetType',
    'UsernameSource',
]


class CacheIdentityType(str, Enum):
    """
    The type of identity used for the cache
    """
    SYSTEM_ASSIGNED = "SystemAssigned"
    NONE = "None"


class NfsAccessRuleAccess(str, Enum):
    """
    Access allowed by this rule.
    """
    NO = "no"
    RO = "ro"
    RW = "rw"


class NfsAccessRuleScope(str, Enum):
    """
    Scope for this rule. The scope and filter determine which clients match the rule.
    """
    DEFAULT = "default"
    NETWORK = "network"
    HOST = "host"


class ProvisioningStateType(str, Enum):
    """
    ARM provisioning state, see https://github.com/Azure/azure-resource-manager-rpc/blob/master/v1.0/Addendum.md#provisioningstate-property
    """
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELLED = "Cancelled"
    CREATING = "Creating"
    DELETING = "Deleting"
    UPDATING = "Updating"


class StorageTargetType(str, Enum):
    """
    Type of the Storage Target.
    """
    NFS3 = "nfs3"
    CLFS = "clfs"
    UNKNOWN = "unknown"


class UsernameSource(str, Enum):
    """
    This setting determines how the cache gets username and group names for clients.
    """
    AD = "AD"
    LDAP = "LDAP"
    FILE = "File"
    NONE = "None"
